clear matrix
clear mata
clear	
set mem 900m
set mat 800
cap log close
set more 1


**************************************************************************************
*"CEO PAY AND FIRM SIZE: AN UPDATE AFTER THE CRISIS" by Gabaix, Landier and Sauvagnat

*FORMATION DATABASES FOR REPLICATION
*************************************************************************************


*Deflator
**********

*data from http://www.bea.gov/national/nipaweb/TableView.asp?SelectedTable=13&ViewSeries=NO&Java=no&Request3Place=N&3Place=N&FromView=YES&Freq=Year&FirstYear=2006&LastYear=2008&3Place=N&AllYearsChk=YES&Update=Update&JavaBox=no#Mid
*use line 1: Gross domestic product, saved in GDPBEAraw as in webpage
*and then create deflator converting quantities in 2000 dollars

use GDPBEAraw, clear
gen t=gdp if year==2000
egen t2=max(t)
replace gdp=gdp/t2
gen deflator=1/gdp
keep year deflator
rename year yeara
sort yeara
save deflat, replace


************************************************************************************
******************Creation of two datasets with information on CEO and Non-CEO Pay 
************************************************************************************

use execucomp, clear

*Retrieve CEO in Execucomp
***************************

duplicates drop execid year gvkey ,force
egen nceo=sum(ceoann=="CEO"), by(gvkey year)
gen ceoann2=ceoann
egen finceo=max(year) if ceoann=="CEO",by(execid gvkey)
egen FINCEO=max(finceo) ,by(gvkey execid)
replace ceoann2="CEO" if (year>=year(becamece))&year<=FINCEO&FINCEO~=.&becamece~=.&nceo==0
drop ceoann
ren ceoann2 ceoann
tab ceoann 
drop nceo
egen nceo=sum(ceoann=="CEO"), by(gvkey year)
replace ceoann="" if nceo>1

*keep firms with non-missing CEO compensation
**********************************************

keep if ceoann=="CEO"
keep if !missing(tdc1) 
rename year yeara
sort yeara
merge yeara using deflat
keep if _m==3
drop _m
replace tdc1=tdc1*deflat
gen lcomp=ln(tdc1)
keep gvkey yeara lcomp tdc1
destring gvkey, replace
sort gvkey year
save ceopay, replace

use execucomp, clear

*Retrieve CEO in Execucomp
***************************

duplicates drop execid year gvkey ,force
egen nceo=sum(ceoann=="CEO"), by(gvkey year)
gen ceoann2=ceoann
egen finceo=max(year) if ceoann=="CEO",by(execid gvkey)
egen FINCEO=max(finceo) ,by(gvkey execid)
replace ceoann2="CEO" if (year>=year(becamece))&year<=FINCEO&FINCEO~=.&becamece~=.&nceo==0
drop ceoann
ren ceoann2 ceoann
tab ceoann 
drop nceo
egen nceo=sum(ceoann=="CEO"), by(gvkey year)
replace ceoann="" if nceo>1
keep if nceo==1

*keep non-CEO Executives
************************
drop if ceoann=="CEO"

collapse(mean) tdc1, by(gvkey year)
rename year yeara
sort yeara
merge yeara using deflat
keep if _m==3
drop _m
gen lcompexec=ln(tdc1*deflat)
keep gvkey yeara lcompexec
destring gvkey, replace
sort gvkey year
save otherexecpay, replace

**************************************************************
***** Form Dataset to Replicate Tables 1,2 and 3 and Figure 2
**************************************************************

use compustat, clear

*select US-based firms in compustat
***********************************

keep if fic=="USA"
bysort gvkey fyear: keep if _n==1
rename fyear yeara
destring gvkey, replace
destring sic, replace
sort yeara
keep if year>=1991&year<=2010
merge yeara using deflat
drop _m

*Compute firm total value as in Nagel (2010)
********************************************

replace txdb=0 if missing(txdb)
gen equityvalue=prcc_f*abs(csho)*deflat
gen firmvalue=(prcc_f*csho+at-txdb-ceq)*deflat
replace yeara=yeara+1
sort gvkey yeara
save size, replace

replace equityvalue=ln(equityvalue)
replace firmvalue=ln(firmvalue)
merge gvkey yeara using ceopay
keep if _m==3
sort year
by year: egen n=rank(-firmvalue)
replace firmvalue=. if n>1000

gen lincome=ln((oibdp-dp)*deflat)
gen lsales=ln(sale*deflat)
gen xx=firmvalue if n>249&n<251
by year: egen firmvalue250=max(xx)

drop xx 

*famafrench generates 48 Fama-French industries
***********************************************
do famafrench
sort year
by year: egen n2=rank(-equityvalue)
gen xx=equityvalue if n2>249&n2<251
by year: egen equityvalue250=max(xx)
drop xx

gen mktcap=(prcc_f*csho+at-txdb-ceq)*deflat/10^3
gen lnrank=ln(n-1/2)
gen lmktcap=ln(mktcap)

keep lcomp lmktcap lnrank equityvalue equityvalue250 famafrench gvkey year deflator n n2 lincome lsales firmvalue firmvalue250
save replication123F2, replace


**************************************************************
***** Form Dataset to Replicate Tables 5 and 6 and Figure 1
**************************************************************


use ceopay, clear
merge gvkey year using size
keep if _m==3
sort year
by year: egen n=rank(-firmvalue)
keep if n<501
keep gvkey yeara firmvalue equityvalue tdc1
sort gvkey year
save t, replace 

***************************
*Extend JMW and FS indexes
***************************

*Take average CEO compensation of TOP500
******************************************
collapse(mean) tdc1, by(yeara)

*ceoindexes gives compensation indexes (JMW and FS) from 1970 to 2004
**********************************************************************

merge yeara using ceoindexes
sort yeara

*Compute annual increase in average CEO compensation and extend compensation indexes from 2005 to 2011
******************************************************************************************************
gen t=(tdc1-tdc1[_n-1])/tdc1[_n-1]
forvalues i=2005(1)2011{
replace totalcomp=totalcomp[_n-1]*(1+t) if yeara==`i'
replace murphy_totalpay=murphy_totalpay[_n-1]*(1+t) if yeara==`i'
}
keep if yeara>=1970&yeara<=2011
keep totalcomp murphy_totalpay yeara

*Normalize to 1 in 1980
************************
replace totalcomp=(totalcomp/1.3988)
replace murphy_totalpay=(murphy_totalpay/1245.969)
rename totalcomp FS_compensation_index
rename murphy_totalpay JMW_compensation_index
sort yeara
save compindex.dta, replace

****TOP 500 Equity Time Series
use ceopay, clear
merge gvkey year using size
keep if _m==3
drop _m
bysort year: egen n=rank(-equityvalue)
keep if n<501
sort gvkey year
save t3, replace 
use compustat, clear
destring gvkey, replace
keep if fic=="USA"
bysort gvkey fyear: keep if _n==1
rename fyear yeara
keep if year<1991
sort yeara
merge yeara using deflat
keep if _m==3
drop _m
gen equityvalue=(prcc_f*abs(csho))*deflat 
replace year=year+1
bysort year: egen n=rank(-equityvalue)
keep if n<501
sort gvkey year
merge gvkey year using t3
collapse (mean) equityvalue, by(year)
sort yeara
save equity, replace

*Select top 500 in Compustat before 1992 and top 500 in Compustat with non-missing CEO compensation in Execucomp after 1992
****************************************************************************************************************************
use compustat, clear
keep if fic=="USA"
destring gvkey, replace
bysort gvkey fyear: keep if _n==1
rename fyear yeara
keep if year<1991
sort yeara
merge yeara using deflat
keep if _m==3
drop _m
replace txdb=0 if missing(txdb)
gen firmvalue=(prcc_f*abs(csho)+at-ceq-txdb)*deflat 
drop if missing(firmvalue)
keep gvkey year firmvalue sic
replace year=year+1
sort year
by year: egen n=rank(-firmvalue)
keep if n<501
sort gvkey year
merge gvkey year using t

collapse (mean) firmvalue, by(year)
sort yeara
merge yeara using equity
drop _m
sort yeara
merge yeara using compindex

gen norm=firmvalue if yeara==1980
gen norm2=equityvalue if yeara==1980
egen normkt=max(norm)
egen normkt2=max(norm2)
drop norm norm2 

replace firmvalue=firmvalue/normkt
replace equityvalue=equityvalue/normkt2

drop normkt normkt2

label variable JMW_compensation_index "JMW Compensation Index"
label variable FS_compensation_index "FS Compensation Index" 
label variable firmvalue "TOP 500 Firm Value"
label variable equityvalue "TOP 500 Equity Value"
drop _m
save replication56F1, replace


**************************************************************
***** Form Dataset to Replicate Tables 7 and 8
**************************************************************

use compustat, clear
keep if fic=="USA"
bysort gvkey fyear: keep if _n==1
rename fyear yeara
destring gvkey, replace
destring sic, replace
sort yeara
merge yeara using deflat
drop _m
replace yeara=yeara+1
sort gvkey yeara
merge gvkey yeara using otherexecpay
keep if _m==3
replace txdb=0 if missing(txdb)
gen firmvalue=ln((prcc_f*csho+at-txdb-ceq)*deflat)
drop if firmvalue==.
sort year
by year: egen n=rank(-firmvalue)
replace firmvalue=. if n>1000
gen equityvalue=ln(prcc_f*abs(csho)*deflat)
gen xx=firmvalue if n>249&n<251
by year: egen firmvalue250=max(xx)
drop xx 

*famafrench generates 48 Fama-French industries
***********************************************
do famafrench
sort year
by year: egen n2=rank(-equityvalue)
replace equityvalue=. if n2>1000
gen xx=equityvalue if n2>249&n2<251
by year: egen equityvalue250=max(xx)
drop xx
keep lcompexec equityvalue equityvalue250 famafrench gvkey year deflator n n2 firmvalue firmvalue250
save replication78, replace
